package com.mortals.xhx.module.customer.service;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.ICRUDService;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.customer.model.CustomerEntityExt;

import java.util.Map;

/**
* CustomerService
*
* 客户管理 service接口
*
* @author zxfei
* @date 2022-06-08
*/
public interface CustomerService extends ICRUDService<CustomerEntity,Long>{

    Result<CustomerEntityExt> findExt(CustomerEntity params, PageInfo pageInfo, Context context) throws AppException;

    /**
     * 客户登录
     * @param loginName
     * @param password
     * @param loginIp
     * @return
     * @throws AppException
     */
    CustomerEntity doLogin(String loginName, String password, String loginIp) throws AppException;


    /**
     * 用户修改个人信息
     * @param params
     * @param context
     * @return
     * @throws AppException
     */
    CustomerEntity updateByPersonal(CustomerEntity params, Context context) throws AppException;

    /**
     * 用户修改个人密码
     * @param params
     * @param context
     * @return
     * @throws AppException
     */
    CustomerEntity changePassword(CustomerEntity params, Context context) throws AppException;


    /**
     * 管理员修改密码
     * @param params
     * @param context
     * @throws AppException
     */
    void changePasswordByAdmin(CustomerEntity params, Context context) throws AppException;

    /**
     * 用户情况统计
     * @return
     */
    Map<String,Object> getCustomerCensus();

    /**
     * 发送手机验证码
     * @param mobileNumber
     * @throws AppException
     */
    void sendSmsVerifyCode(String mobileNumber) throws AppException;
    /**
     * 手机验证码登录
     * @param mobileNumber
     * @param verifyCode
     * @param loginIp
     * @return
     * @throws AppException
     */
    CustomerEntity doSmsLogin(String mobileNumber, String verifyCode, String loginIp) throws AppException;

    /**
     * 微信扫码登录
     * @param openId
     * @param loginIp
     * @return
     * @throws AppException
     */
    CustomerEntity doWeChatLogin(String openId, String loginIp) throws AppException;

}